==> RAppArmor_0.5.0.tar.gz: RAppArmor/man/rlimit_rttime.Rd <==
\name{rlimit_rttime}
\alias{rlimit_rttime}
\title{Limit real-time cpu}
\usage{
  rlimit_rttime(hardlim, softlim = hardlim, pid = 0)
}
\arguments{
  \item{hardlim}{time in microsec}

  \item{softlim}{time in microsec}

  \item{pid}{id of the target process}
}
\description{
  Specifies a limit (in microseconds) on the amount of CPU
  time that a process scheduled under a real-time
  scheduling policy may consume without making a blocking
  system call.
}
\details{
  Specifies a limit (in microseconds) on the amount of CPU
  time that a process scheduled under a real-time
  scheduling policy may consume without making a blocking
  system call. For the purpose of this limit, each time a
  process makes a blocking system call, the count of its
  consumed CPU time is reset to zero. The CPU time count is
  not reset if the process continues trying to use the CPU
  but is preempted, its time slice expires, or it calls
  sched_yield(2). Upon reaching the soft limit, the process
  is sent a SIGXCPU signal. If the process catches or
  ignores this signal and continues consuming CPU time,
  then SIGXCPU will be generated once each second until the
  hard limit is reached, at which point the process is sent
  a SIGKILL signal. The intended use of this limit is to
  stop a runaway real-time process from locking up the
  system.
}
\examples{
#load lib
library(RAppArmor)

#current limit
rlimit_as();

#set hard limit
rlimit_as(1e9);

#set separate hard and soft limit. 
rlimit_as(1e9, 1e8);

#soft limits can be elevated
rlimit_as(soft = 1e7);
rlimit_as(soft = 1e9);

#set other limits
rlimit_core(1e9);
rlimit_data(1e9);
rlimit_fsize(1e9);
rlimit_memlock(10000);
rlimit_msgqueue(1e5);
rlimit_nofile(10);
rlimit_nproc(100);
rlimit_rttime(1e9);
rlimit_sigpending(1e4);
rlimit_stack(1000);
rlimit_cpu(10);
}
\seealso{
  Other rlimit: \code{\link{rlimit_as}},
  \code{\link{rlimit_core}}, \code{\link{rlimit_cpu}},
  \code{\link{rlimit_data}}, \code{\link{rlimit_fsize}},
  \code{\link{rlimit_memlock}},
  \code{\link{rlimit_msgqueue}}, \code{\link{rlimit_nice}},
  \code{\link{rlimit_nofile}}, \code{\link{rlimit_nproc}},
  \code{\link{rlimit_rtprio}},
  \code{\link{rlimit_sigpending}},
  \code{\link{rlimit_stack}}
}

==> RAppArmor_0.6.0.tar.gz: RAppArmor/man/rlimit_rttime.Rd <==
\name{rlimit_rttime}
\alias{rlimit_rttime}
\title{Limit real-time cpu}
\usage{
  rlimit_rttime(hardlim, softlim = hardlim, pid = 0,
    verbose = TRUE)
}
\arguments{
  \item{hardlim}{time in microsec}

  \item{softlim}{time in microsec}

  \item{pid}{id of the target process}

  \item{verbose}{print some C output (TRUE/FALSE)}
}
\description{
  Specifies a limit (in microseconds) on the amount of CPU
  time that a process scheduled under a real-time
  scheduling policy may consume without making a blocking
  system call.
}
\details{
  Specifies a limit (in microseconds) on the amount of CPU
  time that a process scheduled under a real-time
  scheduling policy may consume without making a blocking
  system call. For the purpose of this limit, each time a
  process makes a blocking system call, the count of its
  consumed CPU time is reset to zero. The CPU time count is
  not reset if the process continues trying to use the CPU
  but is preempted, its time slice expires, or it calls
  sched_yield(2). Upon reaching the soft limit, the process
  is sent a SIGXCPU signal. If the process catches or
  ignores this signal and continues consuming CPU time,
  then SIGXCPU will be generated once each second until the
  hard limit is reached, at which point the process is sent
  a SIGKILL signal. The intended use of this limit is to
  stop a runaway real-time process from locking up the
  system.
}
\examples{
#load lib
library(RAppArmor)

#current limit
rlimit_as();

#set hard limit
rlimit_as(1e9);

#set separate hard and soft limit. 
rlimit_as(1e9, 1e8);

#soft limits can be elevated
rlimit_as(soft = 1e7);
rlimit_as(soft = 1e9);

#set other limits
rlimit_core(1e9);
rlimit_data(1e9);
rlimit_fsize(1e9);
rlimit_memlock(10000);
rlimit_msgqueue(1e5);
rlimit_nofile(10);
rlimit_nproc(100);
rlimit_rttime(1e9);
rlimit_sigpending(1e4);
rlimit_stack(1000);
rlimit_cpu(10);
}
\seealso{
  Other rlimit: \code{\link{rlimit_as}},
  \code{\link{rlimit_core}}, \code{\link{rlimit_cpu}},
  \code{\link{rlimit_data}}, \code{\link{rlimit_fsize}},
  \code{\link{rlimit_memlock}},
  \code{\link{rlimit_msgqueue}}, \code{\link{rlimit_nice}},
  \code{\link{rlimit_nofile}}, \code{\link{rlimit_nproc}},
  \code{\link{rlimit_rtprio}},
  \code{\link{rlimit_sigpending}},
  \code{\link{rlimit_stack}}
}
